==> evue-0.1.4.tar.gz: evue-0.1.4/README.md <==
# evue

> Evue is a high-performance gui framework base an html/css which can run on windows/linux/macos/ios/andriod/rtos! Write once, run everywhere! .

See the [中文文档](https://github.com/scriptiot/evue/blob/master/README-zh.md) for Chinese readme.

## Features

![brief](doc/images/brief.png)


## Framework

+ Evue architecture

> Evue is a high-performance gui framework base an html/css which is platform independence and ui engine independence!

![evue](doc/images/evue.png)


+ Evuecompiler architecture

> Evuecompiler is a compiler which compile evue file to python/javascript code!

![evuecompiler](doc/images/evuecompiler.png)

## Installation
Use the package manager [pip](https://github.com/scriptiot/evue) to install evue.

```bash
pip install evue
```

or
```bash
git clone https://github.com/scriptiot/evue.git
cd evue
python setup.py install # also `pip install ."
```

## Getting started

+ [evue_website](https://github.com/scriptiot/evue/tree/master/examples/evue_website)

```python
cd examples
python evuebroswer.py ./evue_website/project.json
or
python evuebroswer.py ./evue_website/app.py
```

+ [evue_login](https://github.com/scriptiot/evue/tree/master/examples/evue_login)

```python
cd examples
python evuebroswer.py ./evue_login/project.json
or
python evuebroswer.py ./evue_login/app.py
```

## Evue Studio

> Evue Studio is a develop platform for evue developer to create/compile/deploy evue project!

![designer](doc/images/designer.png)


## Community

+ [Discussions](https://github.com/scriptiot/evue/discussions)
+ [Issues](https://github.com/scriptiot/evue/issues)


## Contribute to this wonderful project

+ `Welcome to contribute to this wonderful project no matter you are a community technical talent or designer talent, or product manager talent or community operation talent, your name will be one of evue contributors!`

+ `if you like evue, you can send email to [ding465398889@163.com], thanks!`


## Contact

> If there is a need for cooperation, please send email/wechat/QQ for more support!

+ Email : ding465398889@163.com
+ WeChat: dragondjf
> ![dragondjf](doc/images/dragondjf.jpg)
+ Evue for IOT
> ![dragondjf](doc/images/QQ.jpg)

## Salute

+ [evm](https://github.com/scriptiot/evm)
+ [lvgl](https://github.com/lvgl/lvgl)
+ [flet](https://github.com/flet-dev/flet)
+ [flutter](https://github.com/flutter/flutter)

==> evue-0.1.5.tar.gz: evue-0.1.5/README.md <==
# evue

> Evue is a high-performance gui framework base an html/css which can run on windows/linux/macos/ios/andriod/rtos! Write once, run everywhere! .

See the [中文文档](https://github.com/scriptiot/evue/blob/master/README-zh.md) for Chinese readme.

## Features

![brief](https://github.com/scriptiot/evue/blob/master/doc/images/brief.png)


## Framework

+ Evue architecture

> Evue is a high-performance gui framework base an html/css which is platform independence and ui engine independence!

![evue](https://github.com/scriptiot/evue/blob/master/doc/images/evue.png)


+ Evuecompiler architecture

> Evuecompiler is a compiler which compile evue file to python/javascript code!

![evuecompiler](https://github.com/scriptiot/evue/blob/master/doc/images/evuecompiler.png)

## Installation
Use the package manager [pip](https://github.com/scriptiot/evue) to install evue.

```bash
pip install evue
```

or
```bash
git clone https://github.com/scriptiot/evue.git
cd evue
python setup.py install # also `pip install ."
```

## Getting started

+ [evue_website](https://github.com/scriptiot/evue/tree/master/examples/evue_website)

```python
cd examples
python evuebroswer.py ./evue_website/project.json
or
python evuebroswer.py ./evue_website/app.py
```

+ [evue_login](https://github.com/scriptiot/evue/tree/master/examples/evue_login)

```python
cd examples
python evuebroswer.py ./evue_login/project.json
or
python evuebroswer.py ./evue_login/app.py
```

## Evue Studio

> Evue Studio is a develop platform for evue developer to create/compile/deploy evue project!

![designer](https://github.com/scriptiot/evue/blob/master/doc/images/designer.png)


## Community

+ [Discussions](https://github.com/scriptiot/evue/discussions)
+ [Issues](https://github.com/scriptiot/evue/issues)


## Contribute to this wonderful project

+ `Welcome to contribute to this wonderful project no matter you are a community technical talent or designer talent, or product manager talent or community operation talent, your name will be one of evue contributors!`

+ `if you like evue, you can send email to [ding465398889@163.com], thanks!`


## Contact

> If there is a need for cooperation, please send email/wechat/QQ for more support!

+ Email : ding465398889@163.com
+ WeChat: dragondjf
> ![dragondjf](https://github.com/scriptiot/evue/blob/master/doc/images/dragondjf.jpg)
+ Evue for IOT
> ![dragondjf](https://github.com/scriptiot/evue/blob/master/doc/images/QQ.jpg)

## Salute

+ [evm](https://github.com/scriptiot/evm)
+ [lvgl](https://github.com/lvgl/lvgl)
+ [flet](https://github.com/flet-dev/flet)
+ [flutter](https://github.com/flutter/flutter)
